import { Dialog, Page } from 'puppeteer-core';
import Generic from './Generic';
import Puth from './Puth';
import PuthContextPlugin from './PuthContextPlugin';
import { Emitter, Handler, WildcardHandler } from './Utils/Emitter';
import Return from './Context/Return';
import { PuthBrowser } from './HandlesBrowsers';
import { ContextStatus, ICommand, IExpectation } from '@puth/core';
import { CdpPage } from 'puppeteer-core/lib/cjs/puppeteer/cdp/Page';
type ContextEvents = {
    'call': any;
    'get': any;
    'set': any;
    'delete': any;
    'destroying': any;
    'browser:connected': {
        browser: PuthBrowser;
    };
    'browser:disconnected': {
        browser: PuthBrowser;
    };
    'page:created': {
        browser: PuthBrowser;
        page: Page;
    };
    'page:closed': {
        browser: PuthBrowser;
        page: Page;
    };
    'call:apply:before': {
        command: ICommand | undefined;
        page: CdpPage;
    };
    'call:apply:after': {
        command: ICommand | undefined;
        page: CdpPage;
    };
    'call:apply:error': {
        error: any;
        command: ICommand | undefined;
        page: CdpPage;
    };
    'call:expectation:error': {
        expectation: IExpectation;
        command: ICommand | undefined;
        page: CdpPage;
    };
};
type ContextCaches = {
    dialog: Map<Page, Dialog>;
};
declare class Context extends Generic {
    private readonly _id;
    private readonly _type;
    private readonly _puth;
    private readonly _emitter;
    private readonly _createdAt;
    private _lastActivity;
    private options;
    private plugins;
    private eventFunctions;
    private cleanupCallbacks;
    browsers: PuthBrowser[];
    caches: ContextCaches;
    shouldSnapshot: boolean;
    test: {
        name: string;
        status: ContextStatus.FAILED | ContextStatus.SUCCESSFUL | ContextStatus.PENDING;
    };
    destroying: boolean;
    constructor(puth: Puth, options?: any);
    setup(): Promise<void>;
    connectBrowser(options: any): Promise<PuthBrowser>;
    createBrowser(options?: any): Promise<PuthBrowser>;
    private handleNewBrowser;
    destroy(options?: any): Promise<boolean>;
    destroyBrowserByBrowser(browser: any): Promise<void>;
    private removeBrowser;
    isPageBlockedByDialog(page: any): boolean;
    private trackBrowser;
    private trackPage;
    getSnapshotsByType(type: any): Return;
    registerEventListenerOn(object: any, event: any, func: any): void;
    removeEventListenersFrom(object: any): void;
    testFailed(): void;
    testSuccess(): void;
    testSucceeded(): void;
    saveContextSnapshot(options: any): Promise<void>;
    private createCommandInstance;
    callAll(calls: any): Promise<any[]>;
    callAny(calls: any): Promise<any[]>;
    callRace(calls: any): Promise<any[]>;
    call(packet: any): Promise<any>;
    private handleCallApply;
    private handleCallApplyAfter;
    resolveReturnValue(action: any, returnValue: any): any;
    isObjectSerializable(object: any): boolean;
    isValueSerializable(value: any): boolean;
    get(action: any): Promise<{
        id: string;
        type: string;
        represents: any;
    } | Return | {
        type: string;
        code: string;
        message: string;
    }>;
    set(action: any): Promise<{
        type: string;
        code: string;
        message: string;
    } | undefined>;
    delete(action: any): Promise<{
        type: string;
        code: string;
        message: string;
    } | undefined>;
    saveTemporaryFile(name: any, content: any): Promise<Return>;
    resolveOn(representation: any): Context | any;
    resolveIfCached(representation: any): any;
    serialize(): {
        id: string;
        type: string;
        represents: string;
        test: {
            name: string;
            status: ContextStatus;
        };
        group: string;
    };
    get id(): string;
    get type(): string;
    get emitter(): Emitter<ContextEvents>;
    get puth(): Puth;
    get createdAt(): number;
    get lastActivity(): number;
    getGroup(): string;
    getPuth(): Puth;
    getPlugins(): PuthContextPlugin[];
    getTimeout(options?: any): any;
    on<Key extends keyof ContextEvents>(type: Key, handler: Handler<ContextEvents[Key]>): void;
    on(type: '*', handler: WildcardHandler<ContextEvents>): void;
    off<Key extends keyof ContextEvents>(type: Key, handler: Handler<ContextEvents[Key]>): void;
    off(type: '*', handler: WildcardHandler<ContextEvents>): void;
    emit<Key extends keyof ContextEvents>(type: Key, event: ContextEvents[Key]): void;
    emit<Key extends keyof ContextEvents>(type: undefined extends ContextEvents[Key] ? Key : never): void;
    emitAsync<Key extends keyof ContextEvents>(type: Key, event: ContextEvents[Key]): Promise<void>;
    emitAsync<Key extends keyof ContextEvents>(type: undefined extends ContextEvents[Key] ? Key : never): Promise<void>;
}
export default Context;
